const BASE_URL = "http://rise.3594.pgw.jp";

function displayMessage(message, success) {
    const statusMessageElement = document.getElementById("statusMessageForOption");
    statusMessageElement.textContent = message;
    statusMessageElement.style.color = success ? "green" : "red";
    setTimeout(() => {
        statusMessageElement.textContent = "";
    }, 3000);
}


// 編成画面からカード情報を取得する
async function getCardData() {
    const settingId = 110;
    const url = "https://g12010355.sp.pf.mbga.jp/?url=https%3A%2F%2Fmbga-sp.daisenran.jp%2Fuser%2Fequip_list_sp.aspx%3Fecat%3D0%26did%3D1%26crp%3D1%26rnd%3D432843&guid=ON";

    const tab = await new Promise((resolve) => {
        chrome.tabs.create({ url: url }, (tab) => {
            resolve(tab);
        });
    });
    await chrome.storage.local.set({ [`settingId_${tab.id}`]: settingId });

    await new Promise((resolve) => {
        chrome.tabs.onUpdated.addListener(function listener(tabId, changeInfo) {
            if (tabId === tab.id && changeInfo.status === 'complete') {
                chrome.tabs.onUpdated.removeListener(listener);
                resolve();
            }
        });
    });
    await bsleep(3000); // データの取得が完了するまで待つ

    // 所持アビリスト
    const cardDataKey = 'cardData';
    const cardData = await new Promise((resolve) => {
        chrome.storage.local.get([cardDataKey], function (result) {
            if (chrome.runtime.lastError) {
                console.error(chrome.runtime.lastError);
                resolve(null);
            } else {
                resolve(result[cardDataKey]);
            }
        });
    });
    return cardData;
}


// CSS用
function getGGSG(ggsg) {
    if (ggsg.value == 8) {
        return "ggsg-gi";
    }
    else if (ggsg.value == 4) {
        return "ggsg-go";
    }
    else if (ggsg.value == 2) {
        return "ggsg-shoku";
    }
    else if (ggsg.value == 1) {
        return "ggsg-gun";
    }
    return;
}


async function bsleep(waitMsec) {
    var startMsec = new Date();
    while (new Date() - startMsec < waitMsec) {
        await delay(1);
    }
}


async function delay(ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
}


// BOM つきの UTF-8 ファイル生成
function createBOM_UTF8(str) {
    const uint8Array = new TextEncoder().encode('\uFEFF' + str); // '\uFEFF' は BOM
    return new Blob([uint8Array], { type: 'text/csv' });
}


// ----------------------------------------------------------------------------------------
// ストレージ読み書き

async function getProfile() {
    return await new Promise((resolve) => {
        chrome.storage.local.get('Profile', function (result) {
            const storedProfile = result['Profile'];
            console.log('Data retrieved from local storage:', storedProfile);
            resolve(storedProfile);
        });
    });
}
